dart_nostr library

Classes

LegacyNostrRelayTransport
Nostr
This class is responsible for handling the connection to all relays.
NostrClient
NostrClientOptions
NostrCountEvent
NostrCountResponse
NostrCryptoUtils
NostrDataEntitiesStream
Represents a holde class for the stream of raw Nostr data entities and the subscription id.
NostrDefaults
Default configuration and constants for Nostr.
NostrEvent
This represents a low level Nostr event that requires setting all fields manually, which requires you to doo all encodings... You can use NostrEvent.fromPartialData to create an event with less fields and lower complexity..
NostrEventOkCommand
The ok command that is sent to the server when an event is accepted or declined.
NostrEventsStream
Represents a holde class for the stream of nostr events and the subscription id.
NostrFailure
NostrFailureResult<T>
NostrFilter
NostrFilter is a filter that can be used to match events.
NostrFilterBuilder
Builder for creating NostrFilter instances with a fluent API.
NostrKeyPairs
This class is responsible for generating, handling and signing keys. It is used by the NostrClient to sign messages.
NostrLogger
General utils to be used in a whole Nostr instance.
NostrNotice
NostrRelayTransport
NostrRequest
NostrRequest is a request to subscribe to a set of events that match a set of filters with a given subscriptionId.
NostrRequestClose
A request to close a subscription with a given subscription id.
NostrRequestEoseCommand
NostrResult<T>
NostrRetryPolicy
Policy for retrying failed operations with configurable backoff strategies.
NostrServices
NostrSuccess<T>
RelayInformations
SubscriptionManager
Manages the lifecycle of event subscriptions with automatic cleanup and tracking.
SubscriptionMetadata
Metadata for a subscription.
SubscriptionStatistics
Statistics for subscriptions.

Extensions

NostrEventsStreamExtensions on NostrEventsStream
Convenience extensions for NostrEventsStream.
NostrRequestExtensions on NostrRequest
Convenience extensions for NostrRequest and NostrEventsStream.

Exceptions / Errors

NostrException