NostrDefaults class

Default configuration and constants for Nostr.

Constructors

NostrDefaults()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaultConnectTimeoutSeconds → const int
Default connection timeout in seconds.
defaultEventLimit → const int
Default event limit per subscription.
defaultLogLevel → const String
Default logging level.
defaultReadTimeoutSeconds → const int
Default read timeout in seconds.
defaultRelays → const List<String>
Default relay URLs to use when none are specified. These are well-known, stable Nostr relays.
defaultRetryPolicy → const String
Default retry policy for network operations.