NostrResult<T> class sealed

Implementers

Properties

failureOrNull NostrFailure?
no setter
hashCode int
The hash code for this object.
no setterinherited
isFailure bool
no setter
isSuccess bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
valueOrNull → T?
no setter

Methods

flatMap<R>(NostrResult<R> mapper(T value)) NostrResult<R>
fold<R>(R onSuccess(T value), R onFailure(NostrFailure failure)) → R
map<R>(R mapper(T value)) NostrResult<R>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited