ConnectionPoolStatistics class

Statistics for the connection pool.

Constructors

ConnectionPoolStatistics({required int totalConnections, required int availableConnections, required int inUseConnections, required double poolUtilization})

Properties

availableConnections int
final
hashCode int
The hash code for this object.
no setterinherited
inUseConnections int
final
poolUtilization double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalConnections int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited