ErrorEvent class

Error event for tracking.

Constructors

ErrorEvent({required String relayUrl, required ErrorType errorType, required int attemptNumber, required DateTime timestamp, String? errorMessage})

Properties

attemptNumber int
final
errorMessage String?
final
errorType ErrorType
final
hashCode int
The hash code for this object.
no setterinherited
relayUrl String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp DateTime
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited