SubscriptionStatistics class

Statistics for subscriptions.

Constructors

SubscriptionStatistics({required int totalSubscriptions, required int totalEventCount, required double averageEventsPerSubscription, required int oldestSubscriptionAgeSeconds, required int newestSubscriptionAgeSeconds})

Properties

averageEventsPerSubscription double
final
hashCode int
The hash code for this object.
no setterinherited
newestSubscriptionAgeSeconds int
final
oldestSubscriptionAgeSeconds int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalEventCount int
final
totalSubscriptions int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited