nostr/model/export library

Classes

NostrCountEvent
NostrCountResponse
NostrDataEntitiesStream
Represents a holde class for the stream of raw Nostr data entities and the subscription id.
NostrEvent
This represents a low level Nostr event that requires setting all fields manually, which requires you to doo all encodings... You can use NostrEvent.fromPartialData to create an event with less fields and lower complexity..
NostrEventOkCommand
The ok command that is sent to the server when an event is accepted or declined.
NostrEventsStream
Represents a holde class for the stream of nostr events and the subscription id.
NostrFilter
NostrFilter is a filter that can be used to match events.
NostrNotice
NostrRequest
NostrRequest is a request to subscribe to a set of events that match a set of filters with a given subscriptionId.
NostrRequestClose
A request to close a subscription with a given subscription id.
NostrRequestEoseCommand
RelayInformations