nostr/model/nostr_events_stream library

Classes

NostrDataEntitiesStream
Represents a holde class for the stream of raw Nostr data entities and the subscription id.
NostrEventsStream
Represents a holde class for the stream of nostr events and the subscription id.