NostrNotice class

Constructors

NostrNotice({required String message, String? relayUrl})
const
NostrNotice.fromDecodedMessage(List decoded)
Creates a NostrNotice from an already-decoded relay message list. Attach the relay source via copyWith after construction.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
relayUrl String?
The URL of the relay that sent this notice. Populated when the notice is received from a relay connection.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

copyWith({String? message, String? relayUrl}) NostrNotice
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

canBeDeserialized(String dataFromRelay) bool
fromRelayMessage(String data) NostrNotice