NostrClient class

Constructors

NostrClient({required NostrRelayTransport transport, required NostrLogger logger, NostrClientOptions options = const NostrClientOptions(), SubscriptionManager? subscriptionManager})

Properties

connectedRelays List<String>
no setter
hashCode int
The hash code for this object.
no setterinherited
isConnected bool
no setter
logger NostrLogger
final
options NostrClientOptions
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subscriptionManager SubscriptionManager?
final
transport NostrRelayTransport
final

Methods

closeAllSubscriptions() → void
closeSubscription(String subscriptionId, [String? relay]) → void
connect(List<String> relays) Future<NostrResult<void>>
count(NostrCountEvent event, {List<String>? relays}) Future<NostrResult<NostrCountResponse>>
disconnect() Future<NostrResult<void>>
getActiveSubscriptions() Map<String, SubscriptionMetadata>
getSubscriptionStatistics() SubscriptionStatistics
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
publish(NostrEvent event, {List<String>? relays}) Future<NostrResult<NostrEventOkCommand>>
subscribe(NostrRequest request, {List<String>? relays}) NostrResult<NostrEventsStream>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited