NostrFilterBuilder class
Builder for creating NostrFilter instances with a fluent API.
Constructors
- NostrFilterBuilder()
- Builder for creating NostrFilter instances with a fluent API.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addTag(
String tagName, String value) → NostrFilterBuilder - Add a single custom tag filter.
-
build(
) → NostrFilter - Build the NostrFilter.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reset(
) → NostrFilterBuilder - Reset the builder to default state.
-
since(
DateTime since) → NostrFilterBuilder - Set the since timestamp.
-
toString(
) → String -
A string representation of this object.
inherited
-
until(
DateTime until) → NostrFilterBuilder - Set the until timestamp.
-
withAuthor(
String author) → NostrFilterBuilder - Add a single author to the filter.
-
withAuthors(
List< String> authors) → NostrFilterBuilder - Add authors to the filter.
-
withEventId(
String eventId) → NostrFilterBuilder - Add a single referenced event ID to the filter.
-
withEventIds(
List< String> eventIds) → NostrFilterBuilder - Add referenced event IDs to the filter.
-
withKind(
int kind) → NostrFilterBuilder - Add a single kind to the filter.
-
withKinds(
List< int> kinds) → NostrFilterBuilder - Add kinds to the filter.
-
withLimit(
int limit) → NostrFilterBuilder - Set the limit.
-
withPubkey(
String pubkey) → NostrFilterBuilder - Add a single referenced pubkey to the filter.
-
withPubkeys(
List< String> pubkeys) → NostrFilterBuilder - Add referenced pubkeys to the filter.
-
withTag(
String tagName, List< String> values) → NostrFilterBuilder - Add a custom tag filter.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited