NostrFailureResult<T> class
final
- Inheritance
-
- Object
- NostrResult<
T> - NostrFailureResult
Constructors
- NostrFailureResult(NostrFailure failure)
-
const
Properties
- failure → NostrFailure
-
final
- failureOrNull → NostrFailure?
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isFailure → bool
-
no setterinherited
- isSuccess → bool
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- valueOrNull → T?
-
no setterinherited
Methods
-
flatMap<
R> (NostrResult< R> mapper(T value)) → NostrResult<R> -
inherited
-
fold<
R> (R onSuccess(T value), R onFailure(NostrFailure failure)) → R -
inherited
-
map<
R> (R mapper(T value)) → NostrResult< R> -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited