LifeCycleManager mixin
- Superclass constraints
Properties
-
activeSubscriptions
→ Map<
String, SubscriptionMetadata> -
Active managed subscriptions.
no setterinherited
- bech32 → NostrBech32
-
Bech32 encoding surface.
no setterinherited
- client → NostrClient
-
Enterprise facade with typed result and resilience APIs.
no setterinherited
-
connectedRelays
→ List<
String> -
High-level relay list known by the active client.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isConnected → bool
-
Whether the high-level client currently has active relay connections.
no setterinherited
- keys → NostrKeys
-
Key management surface.
no setterinherited
- relays → NostrRelays
-
Advanced low-level relay surface.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- services ↔ NostrServices
-
latefinalinherited
- subscriptions → SubscriptionManager
-
Subscription tracking surface.
no setterinherited
- subscriptionStatistics → SubscriptionStatistics
-
Aggregate managed subscription metrics.
no setterinherited
- utils → NostrUtils
-
Utility helpers surface.
no setterinherited
Methods
-
closeAllSubscriptions(
) → void -
Close all client-tracked subscriptions.
inherited
-
connect(
List< String> relays) → Future<NostrResult< void> > -
Connect with the enterprise client facade.
inherited
-
connectDefaults(
) → Future< NostrResult< void> > -
Connect using package defaults.
inherited
-
count(
NostrCountEvent countEvent, {List< String> ? relays}) → Future<NostrResult< NostrCountResponse> > -
Execute a count request through the enterprise client facade.
inherited
-
disableLogs(
) → void -
This method will disable the logs of the library.
inherited
-
disconnect(
) → Future< NostrResult< void> > -
Disconnect and cleanup tracked subscriptions.
inherited
-
dispose(
) → Future< bool> - Clears and frees all the resources used by this instance.
-
enableLogs(
) → void -
This method will enable the logs of the library.
inherited
-
filterBuilder(
) → NostrFilterBuilder -
Create a filter builder for fluent API.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
publish(
NostrEvent event, {List< String> ? relays}) → Future<NostrResult< NostrEventOkCommand> > -
Publish an event through the enterprise client facade.
inherited
-
subscribe(
NostrFilter filter, {List< String> ? relays}) → NostrResult<NostrEventsStream> -
Convenience method to start an event subscription.
Shortcut for a typed request subscription with one filter.
inherited
-
subscribeFilters(
List< NostrFilter> filters, {List<String> ? relays}) → NostrResult<NostrEventsStream> -
Convenience method to start multiple event subscriptions.
Shortcut for starting a subscription with multiple filters.
inherited
-
subscribeRequest(
NostrRequest request, {List< String> ? relays}) → NostrResult<NostrEventsStream> -
Start a typed request subscription through the enterprise client facade.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited