PooledConnection class
Represents a pooled connection.
Constructors
- PooledConnection({required String relayUrl})
Properties
- createdAt ↔ DateTime
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- isInUse ↔ bool
-
getter/setter pair
- lastUsedAt ↔ DateTime
-
getter/setter pair
- relayUrl → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- webSocket ↔ dynamic
-
getter/setter pair
Methods
-
getAgeInSeconds(
) → int - Get connection age in seconds.
-
markAsAvailable(
) → void - Mark connection as available.
-
markAsInUse(
) → void - Mark connection as in use.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited