RelayHealthStatus class
Represents the health status of a relay.
Constructors
- RelayHealthStatus({required String url, required bool isHealthy, required DateTime lastCheckedAt})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isHealthy → bool
-
final
- lastCheckedAt → DateTime
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- url → String
-
final
Methods
-
copyWith(
{String? url, bool? isHealthy, DateTime? lastCheckedAt}) → RelayHealthStatus -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited