RelayPoolStatistics class
Statistics for the relay pool.
Constructors
Properties
- averageConnectionsPerRelay → double
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- healthyRelays → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalActiveConnections → int
-
final
- totalRelays → int
-
final
- unhealthyRelays → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited