SubscriptionMetadata class
Metadata for a subscription.
Constructors
-
SubscriptionMetadata({required String subscriptionId, required List<
NostrFilter> filters, required List<String> relays, required DateTime createdAt, required int eventCount, required DateTime? lastEventAt})
Properties
- createdAt → DateTime
-
final
- eventCount → int
-
final
-
filters
→ List<
NostrFilter> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lastEventAt → DateTime?
-
final
-
relays
→ List<
String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subscriptionId → String
-
final
Methods
-
copyWith(
{String? subscriptionId, List< NostrFilter> ? filters, List<String> ? relays, DateTime? createdAt, int? eventCount, DateTime? lastEventAt}) → SubscriptionMetadata -
getAgeInSeconds(
) → int - Calculate subscription age in seconds.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited