NostrClientOptions class
Constructors
- NostrClientOptions({Duration connectionTimeout = const Duration(seconds: 10), Duration requestTimeout = const Duration(seconds: 15), NostrRetryPolicy retryPolicy = const NostrRetryPolicy(), bool failFast = false})
-
const
Properties
- connectionTimeout → Duration
-
final
- failFast → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- requestTimeout → Duration
-
final
- retryPolicy → NostrRetryPolicy
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{Duration? connectionTimeout, Duration? requestTimeout, NostrRetryPolicy? retryPolicy, bool? failFast}) → NostrClientOptions -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited